Secord order system (MATLAB module example)
-------------------------------------------

This example computes time and frequency responses for a second-order
system using the MATLAB compatibility module.

Code
....
.. literalinclude:: secord-matlab.py
   :language: python
   :linenos:


Notes
.....

1. The environment variable `PYCONTROL_TEST_EXAMPLES` is used for
testing to turn off plotting of the outputs.
